<?php
namespace FiloBlu\Flow\Model\Channel\In;

/**
 * Class Stock
 * @package FiloBlu\Flow\Model\Channel\In
 */
class Stock extends AbstractModel {

    /**
    * @var \Monolog\Logger
    */
    protected $_logger;

    /**
     * Stock constructor.
     * @param \FiloBlu\Flow\Helper\LoggerProvider $loggerProvider
     * @param \FiloBlu\Flow\Model\Channel\Config $channelConfig
     */
    public function __construct(
             \FiloBlu\Flow\Helper\LoggerProvider $loggerProvider,
             \FiloBlu\Flow\Model\Channel\Config $channelConfig
    ) {
        parent::__construct($loggerProvider, $channelConfig);
        $this->_logger = $loggerProvider->getLogger();
    }

    /**
     * @param $channelname
     * @return $this|void
     */
    public function load($channelname) {
        $this->init($channelname);
        return $this;
    }

    /**
     * @param $data
     * @return bool
     */
    public function insertData($data) {

        $parser = $this->getParser();
        $check_mapping_count = $parser->check_mapping_count;


        // $this->_logger->info(__METHOD__);

        $flow = $this->getFile()->getData('flow'); 
        $model =  \Magento\Framework\App\ObjectManager::getInstance()->create('FiloBlu\Flow\Model' . "\\" . $flow);
        
        if (!$model)
            return false;

        $model->setData('meta_file',$this->getFile()->getId());
        $model->setData('meta_processed',0);

        foreach($data as $field => $value){

            // Have a json mapping?
            if(isset($this->map) && $this->map){

                // Get the mapping
                $fieldMap = $this->map->get($field);
                // I need to skip this?
                if(!isset($fieldMap["skip"])) {
                    // Have a destination field? Set that as a "to field"
                    if(isset($fieldMap["to"]) && $fieldMap["to"]){
                        $to_field = $fieldMap["to"];
                        $model->setData("$to_field","$value");
                        // Don't have a destination field but the check_mapping_count is off? Fallback to column name
                    } elseif (!$check_mapping_count){
                        $model->setData("$field","$value");
                    }
                }

                // No json mapping here
            } else {

                // No json and no check then the column name is the field name
                if(!$check_mapping_count){
                    $model->setData("$field","$value");
                } else {
                    // nothing to do here.
                }
            }

        }

        if (!$model->getData('magazzino')){
            $model->setData('magazzino','VEN');
        }

        $model->save();
    }

}
